==> rutorrent-3.9.tar.gz: ruTorrent-3.9/lang/fi.js <==
﻿/*
 * Finnish language file.
 *
 * Initial Author: Spike_B (mr.anon.91@hotmail.com)
 *
 * Author: 
 */

var theUILang =
{
 General			: "Yleiset",
 Downloads			: "Lataukset",
 Connection			: "Yhteydet",
 BitTorrent			: "BitTorrent",
 Advanced			: "Lisäasetukset",
 User_Interface 		: "Käyttöliittymä",
 Confirm_del_torr		: "Vahvista torrent-tiedoston poistaminen",
 Update_GUI_every		: "Paivita käyttöliittymä joka",
 ms				: "ms",
 Alt_list_bckgnd		: "Riveittäin vaihteleva taustaväri",
 Show_cat_start 		: "Näytä ryhmat käynnistettäessä",
 Show_det_start 		: "Nayta yksityiskohdat käynnist.",
 Dnt_start_down_auto		: "älä aloita latauksia automaattisesti",
 Listening_Port 		: "Portti",
 Port_f_incom_conns		: "Saapuville yhteyksille käytettävä portti",
 Rnd_port_torr_start		: "Satunnainen portti aina kun rTorrent käynnistyy",
 Type				: "Tyyppi",
 Bandwidth_Limiting		: "Nopeusrajoitukset",
 Global_max_upl 		: "Lähetysnopeus",
 unlimited			: "rajaton",
 Glob_max_downl 		: "Latausnopeus",
 Add_bittor_featrs		: "BitTorrent-laajennukset",
 En_DHT_ntw			: "Käytä DHT-verkkoa",
 Peer_exch			: "Käyttäjien vaihto  (PEX)",
 Ip_report_track		: "Palvelimelle ilmoitettava IP tai nimi",
 Disabled			: "Ei käytössä",
 Enabled			: "Käytössä",
 ruTorrent_settings		: "Asetukset",
 Doesnt_support 		: "ruTorrent ei tue käyttämääsi selainta.",
 Name				: "Nimi",
 Status 			: "Tila",
 Size				: "Koko",
 Done				: "Valmiina",
 Downloaded			: "Ladattu",
 Uploaded			: "Lahetetty",
 Ratio				: "Suhde",
 DL				: "Latausnopeus",
 UL				: "Lähetysnopeus",
 ETA				: "Aika",
 Label				: "Nimike",
 Peers				: "Lataajat",
 Seeds				: "Jakajat",
 Remaining			: "Jäljellä",
 Priority			: "Tärkeysaste",
 Not_torrent_file		: "Tiedoston täytyy olla torrent-tiedosto.",
 Pausing			: "Tauko",
 Seeding			: "Jakaa",
 Downloading			: "Lataa",
 Checking			: "Tarkistetaan",
 Error				: "Virhe",
 Queued 			: "Jonossa",
 Finished			: "Valmis",
 Stopped			: "Pysäytetty",
 Request_timed_out		: "Yhteys rTorrent:iin aikakatkaistu.",
 Start				: "Aloita",
 Pause				: "Keskeytä",
 Stop				: "Pysaytä",
 Force_recheck			: "Pakota uudelleen tarkistus",
 New_label			: "Uusi nimike...",
 Remove_label			: "Poista nimike",
 Labels 			: "Nimikkeet",
 Remove 			: "Poista",
 Delete_data			: "Poista ladatut tiedostot",
 Remove_and			: "Poista ja ...",
 Details			: "Yksityiskohdat.",
 Properties			: "Ominaisuudet",
 of				: "", //this two creates line
 connected			: "yhdistetty", //  XX of YY connected
 High_priority			: "Korkea",
 Normal_priority		: "Normaali",
 Low_priority			: "Alhainen",
 Dont_download			: "Älä lataa",
 Files				: "Tiedostot",
 Logger 			: "Loki",
 s				: "s", // part of "KB/s"
 bytes				: "tavua",
 KB				: "Kt",
 MB				: "Mt",
 GB				: "Gt",
 TB				: "Tt",
 PB				: "Pt",
 Loading			: "Ladataan...",
 Torrent_file			: "Torrent-tiedosto",
 Torrent_URL			: "Torrentin URL",
 Torrent_properties		: "Torrentin asetukset",
 Trackers			: "Seurantapalvelimet",
 Bandwidth_sett 		: "Rajoitukset",
 Number_ul_slots		: "Lähetyspaikkojen määrä",
 Peer_ex			: "Käyttäjien vaihto",
 Enter_label_prom		: "Anna uusi nimike valituille torrenteille",
 Remove_torrents		: "Poista Torrent(it)",
 Rem_torrents_prompt		: "Haluatko todella poistaa valitut torrentit?",
 All				: "Kaikki",
 Active 			: "Aktiiviset",
 Inactive			: "Toimettomat",
 No_label			: "Ei nimikettä",
 Transfer			: "Siirto",
 Time_el			: "Aikaa kulunut",
 Share_ratio			: "Jakosuhde",
 Down_speed			: "Latausnopeus",
 Ul_speed			: "Lähetysnopeus",
 Wasted 			: "Hylätty",
 Tracker			: "Seurantapalvelin",
 Track_URL			: "Osoite",
 Track_status			: "Tila",
 Created_on			: "Luotu",
 Save_as			: "Kohde",
 Comment			: "Kommentti",
 add_button			: "Lisää tiedosto",
 add_url			: "Lisää sijainti",
 ok				: "OK",
 Cancel 			: "Peruuta",
 mnu_add			: "Lisää torrent",
 mnu_remove			: "Poista",
 mnu_start			: "Aloita",
 mnu_pause			: "Keskeytä",
 mnu_stop			: "Pysäytä",
 mnu_rss			: "RSS-lataaja",
 mnu_settings			: "Asetukset",
 mnu_search			: "Etsi",
 mnu_lang			: "Kieli",
 torrent_add			: "Lisää torrent", /*Caption of torrent add box*/
 time_w 			: "w ", /*for x weeks*/
 time_d 			: "d ", /*for x days remaining*/
 time_h 			: "h ", /*for x hours remaining*/
 time_m 			: "m ", /*for x minutes remaining*/
 time_s 			: "s ", /*for x seconds remaining*/
 Base_directory 		: "Directory",
 Number_Peers_min		: "Minimum number of peers",
 Number_Peers_max		: "Maximum number of peers",
 Tracker_Numwant		: "Wished number of peers",
 Number_Peers_For_Seeds_min	: "Minimum number of peers for seeding",
 Number_Peers_For_Seeds_max	: "Maximum number of peers for seeding",
 Enable_port_open		: "Open listening port",
 dht_port			: "UDP port to use for DHT",
 Other_Limiting 		: "Other Limitations",
 Number_dl_slots		: "Number of download slots",
 Glob_max_memory		: "Maximum memory usage",
 Glob_max_files 		: "Maximum number of open files",
 Glob_max_http			: "Maximum number of open http connections",
 Other_sett			: "Other",
 Directory_For_Dl		: "Default directory for downloads",
 Check_hash			: "Check hash after download",
 Hash				: "Hash",
 DisableTracker 		: "Disable",
 EnableTracker			: "Enable",
 ClientVersion			: "Client",
 Flags				: "Flags",
 ReqTimeout			: "Request timeout",
 GetTrackerMessage		: "Receive messages from tracker",
 Help				: "Help",
 Speed				: "Speed",
 Dont_add_tname 		: "Don't add torrent's name to path",
 Free_Disk_Space		: "Free Disk Space",
 badXMLRPCVersion		: "rTorrent is compiled with incorrect version of xmlrpc-c library, without i8 support. Version must be >= 1.11. Some functionality will be unavailable.",
 badLinkTorTorrent		: "No connection to rTorrent. Check if it is really running. Check $scgi_port and $scgi_host settings in config.php and scgi_port in rTorrent configuration file.",
 badUploadsPath 		: "Webserver user doesn't have read/write/execute access to the torrents directory. You cannot add torrents via ruTorrent.",
 badSettingsPath		: "Webserver user doesn't have read/write/execute access to the settings directory. ruTorrent settings cannot be saved.",
 mnu_help			: "Help",
 badUploadsPath2		: "rTorrent user must have read/execute access to the torrents directory. You cannot add torrents via ruTorrent.",
 View				: "View",
 AsList 			: "As List",
 AsTree 			: "As Tree",
 Group				: "Group",
 SuperSeed			: "Super-seed",
 badTestPath			: "rTorrent user must have read/execute access to the file ./test.sh",
 badSettingsPath2		: "rTorrent user must have read/write/execute access to the settings directory.",
 scrapeDownloaded		: "Downloaded",
 Total				: "Total",
 PCRENotFound			: "PHP PCRE module is not installed. ruTorrent will not work.",
 addTorrentSuccess		: "Torrent was added successfully.",
 addTorrentFailed		: "Failed to add torrent.",
 pnlState			: "State",
 newLabel			: "New Label",
 enterLabel			: "Enter Label",
 UIEffects			: "Show effects for UI elements",
 Plugins			: "Plugins",
 plgName			: "Name",
 plgStatus			: "Status",
 plgLoaded			: "Loaded",
 plgDisabled			: "Not loaded",
 plgVersion			: "Version",
 plgAuthor			: "Author",
 plgDescr			: "Description",
 mnu_go 			: "Go",
 pluginCantStart		: "Plugin failed to start.",
 doFastResume			: "Fast resume",
 innerSearch			: "Local Torrents",
 removeTeg			: "Remove tag",
 errMustBeInSomeHost		: "ruTorrent and rTorrent must be installed on the same host. Plugin will not work.",
 warnMustBeInSomeHost		: "ruTorrent and rTorrent must be installed on the same host. Some functionality will be unavailable.",
 plgShutdown			: "Unload",
 limit				: "Limit",
 speedList			: "Speed Popup List (comma-separated)",
 ClearButton			: "Clear",
 dontShowTimeouts		: "Ignore message about timeouts",
 fullTableRender		: "Full render of large tables",
 showScrollTables		: "Show table contents while scrolling",
 idNotFound			: "rTorrent user can't access 'id' program. Some functionality will be unavailable.",
 gzipNotFound			: "Webserver user can't access 'gzip' program. ruTorrent will not work.",
 cantObtainUser 		: "ruTorrent cannot determine the UID of rTorrent user. Some functionality will be unavailable.",
 retryOnErrorTitle		: "If rTorrent is not available try again after",
 retryOnErrorList		: { 0: "Don't try again", 30: "30 sec", 60: "1 min", 120: "2 min", 300: "5 min", 900: "15 min" },
 statNotFound			: "rTorrent user can't access 'stat' program. Some functionality will be unavailable.",
 statNotFoundW			: "Webserver user can't access 'stat' program. Some functionality will be unavailable.",
 badrTorrentVersion		: "Plugin requires rTorrent version >=",
 badPHPVersion			: "Plugin requires PHP version >=",
 rTorrentExternalNotFoundError	: "Plugin will not work. rTorrent user can't access external program",
 rTorrentExternalNotFoundWarning: "Some functionality will be unavailable. rTorrent user can't access external program",
 webExternalNotFoundError	: "Plugin will not work. Webserver user can't access external program",
 webExternalNotFoundWarning	: "Some functionality will be unavailable. Webserver user can't access external program",
 rTorrentBadScriptPath		: "Plugin will not work. rTorrent user must have read/execute access to the file",
 rTorrentBadPHPScriptPath	: "Plugin will not work. rTorrent user must have read access to the file",
 dependenceError		: "Plugin will not work. It requires plugin(s)",
 peerAdd			: "Add Peer...",
 peerBan			: "Ban",
 peerKick			: "Kick",
 peerSnub			: "Snub",
 peerDetails			: "Details",
 peerUnsnub			: "Unsnub",
 peerAddLabel			: "Enter IP/Hostname[:port]",
 noTorrentList			: "Torrent list not yet available, connection to rTorrent not established.",
 yes				: "yes",
 no				: "no",
 DateFormat			: "Date format",
 DLStrategy			: "Download Strategy",
 prioritizeFirst		: "Leading Chunk First",
 prioritizeLast 		: "Trailing Chunk First",
 prioritizeNormal		: "Normal",
 updateTracker			: "Update Trackers",
 scrapeUpdate			: "Last Updated",
 trkInterval			: "Interval",
 logAutoSwitch			: "Autoswitch to 'Log' tab",
 showLabelSize			: "Show label size",
 phpParameterUnavailable	: "PHP directive register_argc_argv is set to OFF. Change to ON, otherwise some plugins won't work correctly.",
 addTorrentFailedURL		: "Failed to add torrent. Can't retrieve URL.",
 addTorrentFailedFile		: "Failed to add torrent. The retrieved content is not a valid torrent file.",
 addTorrentFailedDirectory	: "Failed to add torrent. Incorrect downloads directory was specified.",
 plgLaunch			: "Launch",
 plgLocked			: "Mandatory",
 phpExtensionNotFoundWarning	: "Some functionality will be unavailable. PHP extension must be installed",
 phpExtensionNotFoundError	: "Plugin will not work. PHP extension must be installed",
 trkPrivate			: "Private",
 dontSet			: "Don't set",
 webBadSessionError		: "Plugin will not work. Webserver user must have execute access to the rtorrent session directory",
 webBadSessionWarning		: "Some functionality will be unavailable. Webserver user must have execute access to the rtorrent session directory",
 Developers			: "Developers",
 Check_new_version		: "Check new version",
 here				: "here",
 Num_No 			: "No.", // This means "Number". To be used as header for number count, e.g.: throttle/ratio plugin
 This_screen			: "This screen",
 About_program			: "About ruTorrent",
 Toggle_menu			: "Toggle menu",
 Toggle_details 		: "Toggle details",
 Toggle_categories		: "Toggle categories",
 Delete_current_torrents	: "Delete current torrent(s)",
 Select_all			: "Select all",
 Deselect_all			: "Deselect all",
 showSpeedInTitle		: "Show speed in the title",
 badTempPath 			: "Webserver user doesn't have read/write/execute access to the tmp directory. ruTorrent will not work.",
 badTempPath2			: "rTorrent user must have read/execute access to the tmp directory. ruTorrent will not work.",
 doRandomizeHash		: "Randomize info hashes for cross-seeding",
 Recreate_files			: "Queue files recreation",
 Address			: "Address",
 PeerDL 			: "Peer DL",
 PeerDownloaded 		: "Peer Downloaded",
 Save_path			: "Save path",
 registerMagnet			: "Try to register magnet protocol handler at start",
 linkTorTorrentRestored		: "Connection to rTorrent established.",
 removeAllTegs			: "Remove all tags"
};

==> rutorrent-4.3.5.tar.gz: ruTorrent-4.3.5/lang/fi.js <==
﻿/*
 * Finnish language file.
 *
 * Initial Author: Spike_B (mr.anon.91@hotmail.com)
 *
 * Author: 
 */

var theUILang =
{
 General			: "Yleiset",
 Downloads			: "Lataukset",
 Connection			: "Yhteydet",
 BitTorrent			: "BitTorrent",
 Format			: "Format",
 Advanced			: "Lisäasetukset",
 User_Interface			: "Käyttöliittymä",
 Confirm_del_torr		: "Vahvista torrent-tiedoston poistaminen",
 Update_GUI_every		: "Paivita käyttöliittymä joka",
 ms				: "ms",
 Alt_list_bckgnd		: "Riveittäin vaihteleva taustaväri",
 Show_cat_start			: "Näytä ryhmat käynnistettäessä",
 Show_det_start			: "Nayta yksityiskohdat käynnist.",
 KeepSearches			: "Keep searches",
 KeepSelectedTab			: "Keep selected tab",
 KeepSelectedLabels		: "Keep selected labels",
 Dnt_start_down_auto		: "älä aloita latauksia automaattisesti",
 Listening_Port			: "Portti",
 Port_f_incom_conns		: "Saapuville yhteyksille käytettävä portti",
 Rnd_port_torr_start		: "Satunnainen portti aina kun rTorrent käynnistyy",
 Type				: "Tyyppi",
 Bandwidth_Limiting		: "Nopeusrajoitukset",
 Global_max_upl			: "Lähetysnopeus",
 unlimited			: "rajaton",
 Glob_max_downl			: "Latausnopeus",
 Add_bittor_featrs		: "BitTorrent-laajennukset",
 En_DHT_ntw			: "Käytä DHT-verkkoa",
 Peer_exch			: "Käyttäjien vaihto (PEX)",
 Ip_report_track		: "Palvelimelle ilmoitettava IP tai nimi",
 Disabled			: "Ei käytössä",
 Enabled			: "Käytössä",
 ruTorrent_settings		: "Asetukset",
 Doesnt_support			: "ruTorrent ei tue käyttämääsi selainta.",
 Name				: "Nimi",
 Status				: "Tila",
 Size				: "Koko",
 Done				: "Valmiina",
 Downloaded			: "Ladattu",
 Uploaded			: "Lahetetty",
 Ratio				: "Suhde",
 DL				: "Latausnopeus",
 UL				: "Lähetysnopeus",
 ETA				: "Aika",
 Label				: "Nimike",
 Peers				: "Lataajat",
 Seeds				: "Jakajat",
 Remaining			: "Jäljellä",
 Priority			: "Tärkeysaste",
 Not_torrent_file		: "Tiedoston täytyy olla torrent-tiedosto.",
 Pausing			: "Tauko",
 Seeding			: "Jakaa",
 Downloading			: "Lataa",
 Checking			: "Tarkistetaan",
 Error				: "Virhe",
 Queued				: "Jonossa",
 Finished			: "Valmis",
 Stopped			: "Pysäytetty",
 Request_timed_out		: "Yhteys rTorrent:iin aikakatkaistu.",
 Start				: "Aloita",
 Pause				: "Keskeytä",
 Stop				: "Pysaytä",
 Force_recheck			: "Pakota uudelleen tarkistus",
 New_label			: "Uusi nimike...",
 Remove_label			: "Poista nimike",
 Labels				: "Nimikkeet",
 Remove				: "Poista",
 Delete_data			: "Poista ladatut tiedostot",
 Remove_and			: "Poista ja",
 Details			: "Yksityiskohdat...",
 Properties			: "Ominaisuudet...",
 of				: "/", // this two creates line
 connected			: "yhdistetty", // XX of YY connected
 High_priority			: "Korkea",
 Normal_priority		: "Normaali",
 Low_priority			: "Alhainen",
 Dont_download			: "Älä lataa",
 Files				: "Tiedostot",
 Logger				: "Loki",
 s				: "s", // part of "KB/s"
 bytes				: "tavua",
 KB				: "Kt",
 MB				: "Mt",
 GB				: "Gt",
 TB				: "Tt",
 PB				: "Pt",
 Loading			: "Ladataan...",
 Torrent_file			: "Torrent-tiedosto",
 Torrent_URL			: "Torrentin URL",
 Torrent_properties		: "Torrentin asetukset",
 Trackers			: "Seurantapalvelimet",
 Bandwidth_sett			: "Rajoitukset",
 Number_ul_slots		: "Lähetyspaikkojen määrä",
 Peer_ex			: "Käyttäjien vaihto",
 Enter_label_prom		: "Anna uusi nimike valituille torrenteille",
 Remove_torrents		: "Poista Torrent(it)",
 Rem_torrents_prompt		: "Haluatko todella poistaa valitut torrentit?",
 All				: "Kaikki",
 Active				: "Aktiiviset",
 Inactive			: "Toimettomat",
 No_label			: "Ei nimikettä",
 Transfer			: "Siirto",
 Time_el			: "Aikaa kulunut",
 Share_ratio			: "Jakosuhde",
 Down_speed			: "Latausnopeus",
 Ul_speed			: "Lähetysnopeus",
 Wasted				: "Hylätty",
 Tracker			: "Seurantapalvelin",
 Track_URL			: "Osoite",
 Track_status			: "Tila",
 Created_on			: "Luotu",
 Save_as			: "Kohde",
 Comment			: "Kommentti",
 add_button			: "Lisää tiedosto",
 add_url			: "Lisää sijainti",
 ok				: "OK",
 Cancel				: "Peruuta",
 mnu_add			: "Lisää torrent",
 mnu_remove			: "Poista",
 mnu_start			: "Aloita",
 mnu_pause			: "Keskeytä",
 mnu_stop			: "Pysäytä",
 mnu_rss			: "RSS-lataaja",
 mnu_settings			: "Asetukset",
 mnu_search			: "Etsi",
 mnu_lang			: "Kieli",
 torrent_add			: "Lisää torrent", /*Caption of torrent add box*/
 time_w				: "w ", /*for x weeks*/
 time_d				: "d ", /*for x days remaining*/
 time_h				: "h ", /*for x hours remaining*/
 time_m				: "m ", /*for x minutes remaining*/
 time_s				: "s ", /*for x seconds remaining*/
 Base_directory			: "Directory",
 Number_Peers_min		: "Minimum number of peers",
 Number_Peers_max		: "Maximum number of peers",
 Tracker_Numwant		: "Wished number of peers",
 Number_Peers_For_Seeds_min	: "Minimum number of peers for seeding",
 Number_Peers_For_Seeds_max	: "Maximum number of peers for seeding",
 Enable_port_open		: "Open listening port",
 dht_port			: "UDP port to use for DHT",
 Other_Limiting			: "Other Limitations",
 Number_dl_slots		: "Number of download slots",
 Glob_max_memory		: "Maximum memory usage",
 Glob_max_files			: "Maximum number of open files",
 Glob_max_http			: "Maximum number of open http connections",
 Open_label         : "Avata",
 Other_sett			: "Other",
 Directory_For_Dl		: "Default directory for downloads",
 Check_hash			: "Check hash after download",
 Hash				: "Hash",
 DisableTracker			: "Disable",
 EnableTracker			: "Enable",
 ClientVersion			: "Client",
 Flags				: "Flags",
 ReqTimeout			: "Request timeout",
 GetTrackerMessage		: "Receive messages from tracker",
 Help				: "Help",
 Speed				: "Speed",
 Dont_add_tname			: "Don't add torrent's name to path",
 Free_Disk_Space		: "Free Disk Space",
 badXMLRPCVersion		: "rTorrent is compiled with incorrect version of xmlrpc-c library, without i8 support. Version must be >= 1.11. Some functionality will be unavailable.",
 badLinkTorTorrent		: "No connection to rTorrent. Check if it is really running. Check $scgi_port and $scgi_host settings in config.php and scgi_port in rTorrent configuration file.",
 badUploadsPath			: "Webserver user doesn't have read/write/execute access to the torrents directory. You cannot add torrents via ruTorrent.",
 badSettingsPath		: "Webserver user doesn't have read/write/execute access to the settings directory. ruTorrent settings cannot be saved.",
 mnu_help			: "Help",
 badUploadsPath2		: "rTorrent user must have read/execute access to the torrents directory. You cannot add torrents via ruTorrent.",
 View				: "View",
 AsList				: "As List",
 AsTree				: "As Tree",
 Group				: "Group",
 SuperSeed			: "Super-seed",
 badTestPath			: "rTorrent user must have read/execute access to the file ./test.sh",
 badSettingsPath2		: "rTorrent user must have read/write/execute access to the settings directory.",
 scrapeDownloaded		: "Downloaded",
 Total				: "Total",
 PCRENotFound			: "PHP PCRE module is not installed. ruTorrent will not work.",
 addTorrentSuccess		: "Torrent was added successfully.",
 addTorrentFailed		: "Failed to add torrent.",
 pnlViews			: "Views",
 NewView			: "New View",
 MoveView			: {base: "Move view", top: "To top", up: "Up", down: "Down", bottom: "To bottom"},
 RenameView			: "Rename view",
 RemoveActiveViews		: "Remove active views",
 SaveCurrentView		: "Save current view",
 showViewPanel			: "Show Views panel",
 showViewLabelSize		: "Show label size in Views panel",
 pnlState			: "State",
 newLabel			: "New Label",
 enterLabel			: "Enter Label",
 UIEffects			: "Show effects for UI elements",
 Plugins			: "Plugins",
 plgName			: "Name",
 plgStatus			: "Status",
 plgLoaded			: "Loaded",
 plgDisabled			: "Not loaded",
 plgVersion			: "Version",
 plgAuthor			: "Author",
 plgDescr			: "Description",
 mnu_go				: "Go",
 pluginCantStart		: "Plugin failed to start.",
 doFastResume			: "Fast resume",
 innerSearch			: "Local Torrents",
 removeTeg			: "Remove tag",
 errMustBeInSomeHost		: "ruTorrent and rTorrent must be installed on the same host. Plugin will not work.",
 warnMustBeInSomeHost		: "ruTorrent and rTorrent must be installed on the same host. Some functionality will be unavailable.",
 plgShutdown			: "Unload",
 limit				: "Limit",
 speedList			: "Speed Popup List (comma-separated)",
 DecimalPlacesSizes		: "Decimal Places of Sizes",
 CatListSizeDecimalPlaces	: "In category list",
 TableSizeDecimalPlaces	: "In tables",
 DetailsSizeDecimalPlaces	: "In general tab",
 OtherSizeDecimalPlaces	: "Other",
 Default	: "Default",
 ClearButton			: "Clear",
 dontShowTimeouts		: "Ignore message about timeouts",
 fullTableRender		: "Full render of large tables",
 showScrollTables		: "Show table contents while scrolling",
 idNotFound			: "rTorrent user can't access 'id' program. Some functionality will be unavailable.",
 gzipNotFound			: "Webserver user can't access 'gzip' program. ruTorrent will not work.",
 cantObtainUser			: "ruTorrent cannot determine the UID of rTorrent user. Some functionality will be unavailable.",
 retryOnErrorTitle		: "If rTorrent is not available try again after",
 retryOnErrorList		: { 0: "Don't try again", 30: "30 sec", 60: "1 min", 120: "2 min", 300: "5 min", 900: "15 min" },
 statNotFound			: "rTorrent user can't access 'stat' program. Some functionality will be unavailable.",
 statNotFoundW			: "Webserver user can't access 'stat' program. Some functionality will be unavailable.",
 badrTorrentVersion		: "Plugin requires rTorrent version >=",
 badPHPVersion			: "Plugin requires PHP version >=",
 rTorrentExternalNotFoundError	: "Plugin will not work. rTorrent user can't access external program",
 rTorrentExternalNotFoundWarning: "Some functionality will be unavailable. rTorrent user can't access external program",
 webExternalNotFoundError	: "Plugin will not work. Webserver user can't access external program",
 webExternalNotFoundWarning	: "Some functionality will be unavailable. Webserver user can't access external program",
 rTorrentBadScriptPath		: "Plugin will not work. rTorrent user must have read/execute access to the file",
 rTorrentBadPHPScriptPath	: "Plugin will not work. rTorrent user must have read access to the file",
 dependenceError		: "Plugin will not work. It requires plugin(s)",
 peerAdd			: "Add Peer...",
 peerBan			: "Ban",
 peerKick			: "Kick",
 peerSnub			: "Snub",
 peerDetails			: "Details",
 peerUnsnub			: "Unsnub",
 peerAddLabel			: "Enter IP/Hostname[:port]",
 noTorrentList			: "Torrent list not yet available, connection to rTorrent not established.",
 yes				: "yes",
 no				: "no",
 DateFormat			: "Date format",
 DLStrategy			: "Download Strategy",
 prioritizeFirst		: "Leading Chunk First",
 prioritizeLast			: "Trailing Chunk First",
 prioritizeNormal		: "Normal",
 updateTracker			: "Update Trackers",
 scrapeUpdate			: "Last Updated",
 trkInterval			: "Interval",
 logAutoSwitch			: "Autoswitch to 'Log' tab",
 showStateLabelSize		: "Show label size in State panel",
 showLabelSize			: "Show label size in Labels panel",
 showSearchLabelSize		: "Show label size in Search panel",
 showCustomLabelTree		: "Show label path tree",
 labelSizeRightAlign		: "Right align size in category list",
 showEmptyPathLabel		: "Show empty path labels",
 showLabelTextOverflow	: "Allow overflow of label text",
 showOpenStatus		: "Show open status in status bar",
 requiresAtLeastRtorrent		: "Requires rTorrent >= {version}", // ... v0.9.7
 phpParameterUnavailable	: "PHP directive register_argc_argv is set to OFF. Change to ON, otherwise some plugins won't work correctly.",
 addTorrentFailedURL		: "Failed to add torrent. Can't retrieve URL.",
 addTorrentFailedFile		: "Failed to add torrent. The retrieved content is not a valid torrent file.",
 addTorrentFailedDirectory	: "Failed to add torrent. Incorrect downloads directory was specified.",
 plgLaunch			: "Launch",
 plgLocked			: "Mandatory",
 phpExtensionNotFoundWarning	: "Some functionality will be unavailable. PHP extension must be installed",
 phpExtensionNotFoundError	: "Plugin will not work. PHP extension must be installed",
 trkPrivate			: "Private",
 dontSet			: "Don't set",
 webBadSessionError		: "Plugin will not work. Webserver user must have execute access to the rtorrent session directory",
 webBadSessionWarning		: "Some functionality will be unavailable. Webserver user must have execute access to the rtorrent session directory",
 Developers			: "Developers",
 Check_new_version		: "Check new version",
 here				: "here",
 Num_No				: "No.", // This means "Number". To be used as header for number count, e.g.: throttle/ratio plugin
 This_screen			: "This screen",
 About_program			: "About ruTorrent",
 Toggle_menu			: "Toggle menu",
 Toggle_details			: "Toggle details",
 Toggle_categories		: "Toggle categories",
 Delete_current_torrents	: "Delete current torrent(s)",
 Select_all			: "Select all",
 Deselect_all			: "Deselect all",
 showSpeedInTitle		: "Show speed in the title",
 speedGraphDuration		: "Duration of speed graph",
 speedGraphDurationOptions		: {600: "10 min", 1800: "30 min", 3600: "1 hr", 10800: "3 hrs"},
 badTempPath			: "Webserver user doesn't have read/write/execute access to the tmp directory. ruTorrent will not work.",
 badTempPath2			: "rTorrent user must have read/execute access to the tmp directory. ruTorrent will not work.",
 doRandomizeHash		: "Randomize info hashes for cross-seeding",
 Recreate_files			: "Queue Files Recreation",
 Address			: "Address",
 PeerDL				: "Peer DL",
 PeerDownloaded			: "Peer Downloaded",
 Save_path			: "Save path",
 registerMagnet			: "Try to register magnet protocol handler at start",
 linkTorTorrentRestored		: "Connection to rTorrent established.",
 removeAllTegs			: "Remove all tags",
 Torrents			: "Torrent(s)",
 copyToClipboardFailed		: "The copy function isn't working in your browser.\nPlease copy this content manually:\n\n",
 copyToClipboardSuccess		: "Copied to clipboard successfully!"
};
